bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 12. Aventiure
___________________________________________________ #### Aventivre wie gvnther sifriden #### zvo der hohzit bat
###### 724 | ### Nv gedaht ovch alle cite | daz gvnthers wip ### wi treit et also hohe | vrov crhiemhilt den lip ### nv ist doch vnser eigen | sifrit ir man ### er hat vns nv vil lange | lvecel dienste getan
###### 725 | ### diz trvch si in ir hercen | vnt wart ovch wol verdeit ### daz si ir vremede waren | daz was ir harte leit ### daz man ir so selten diente | von sifrides lant ### wavon daz were | daz hete si gerne bechant
###### 726 | ### si versvchtez an dem chvenige | ob iz mohte geschehen ### daz si criemhilde | solde noch gesehen ### si reit ez haeinliche | des si da hete mvt ### do dvhte den herren | div rede maezlichen gvt
###### 727 | ### wi moehte wir si bringen | sprach der chvenech rich ### her zv disem lande | daz waere vnmvegelich ### si sitzen vns ce verre | ine getar sis niht gebitten ### des antwurte im vrov prvnnhilt | in einen listigen siten
###### 728 | ### swi hohe riche waere | deheines chveniges man ### swaz im gebvete sin herre | daz sold er doch niht lan ### des ersmielte gvnther | do si daz gesprach ### ern iahes im niht ce dienste | swi diche er sifride sach
###### 729 | ### si sprach vil lieber herre | dvrch den willen min ### so hilf mir daz sifrit | vnt ovch div swester din ### chvmen zv disem lande | daz wir si hie gesehen ### so ne chvnde mir zware | nimmer lieber geshaehen
###### 730 | ### diner swester zvehte | vnt ir wol gezogener mvt ### swenne ich daran gedenche | wi sampfte mir daz tvt ### wi wir ensamt sazen | do ich erste wart din wip ### si mach mit eren minnen | des chvenen sifrides lip
###### 731 | ### si gertes also lange | vnz daz der chvenich sprach ### nv wizet daz ich geste | so gerne nie gesach ### ir mveget mich sampfte vlegen | ich wil di boten min ### nach in beiden senden | daz si vns chomen an den rin
###### 732 | ### do sprach div chveneginne | so svlt ir mir sagen ### wenne ir si welt besenden | oder in welhen tagen ### vnser lieben vrivnde | svln chomen in daz lant ### di ir dar wellet senden | di lat mir werden bechant
###### 733 | ### daz tvn ich sprach der fvrste | drizech miner man ### wil ich dar lazen riten | di hiez er fver sich gan ### bi den enbot er maere | in daz sifrides lant ### ce liebe gap in prvnnhilt | vil harte herlich gewant
###### 734 | ### do sprach der chvenich gvnther | ir recken svlt von mir sagen ### al daz ich dar enbiete | svlt ir niht verdagen ### dem starchem sifride | vnt ovch der swester min ### daz in en darf ce der werlde | niemen holder gesin
###### 735 | ### vnde pittet daz si beide | zv vns chomen an den rin ### daz welle ich vnt min vrowe | immer dienende sin ### vor disen svnewenden | sol er vnd sine man ### sehen hie vil manigen | der im vil grozer eren gan
###### 736 | ### dem chvnige sigemvnde | saget den den dienest min ### daz ich vnd di mine | im immer waege sin ### vnd saget ovch miner swester | daz si niht laze daz ### si ne rite zv zir vrivnden | ir zam ni hohgeciten baz
###### 737 | ### prvnnhilt vnt vte | vnd swaz man da vrowen vant ### di enbvten alle ir dienest | in sifrides lant ### den minnechlichen vrowen | vnt manigem chvenem man ### mit chveneges vrivnde rate | di boten hvben sich dan
###### 738 | ### si fvren reisliche | ir pferht vnd ir gewant ### daz was in chomen allen | do rvmten si daz lant ### in zogete wol ir verte | dar si da wolden varn ### der chvenich hiez mit geleite | di boten vlizechliche bewarn
###### 739 | ### si chomen in drin wochen | geriten in daz lant ### ce nibelvnges bverge | dar waren si gesant ### ce norwaege in der marche | da fvnden si degen ### div ross den boten waren | vil mvede von den langen wegen
###### 740 | ### sifride vnd criemhilt | wart beiden do geseit ### daz ritter dar chomen waren | di trvgen solhiv chleit ### sam man cen bvergende | do der site pflach ### si spranch von einem bette | daran si ruwende lach
###### 741 | ### do bat si ceinem venster | eine magt gan ### div sach den chvenen geren | an dem hove stan ### in vnt di gesellen | di waren dar gesant ### gegen ir herceleide | wi liebiv maere si bevant
###### 742 | ### si sprach zv dem chvenige | nv seht ir wa si stent ### di mit dem starchen geren | vff dem hove gent ### di vns min brvder gvnther | sendet nider den rin ### do sprach der starche sifrit | di svln vns willechomen sin
###### 743 | ### allez das gesinde | lief da man si sach ### ir ietslich besvnder | vil gvetliche sprach ### daz beste daz si chvnden | ce boten do ### sigemvnt der herre | der was ir chvmpfte harte vro
###### 744 | ### do wart geherberget | gere vnt sine man ### div ross hiez man behalten | di boten giengen dan ### da der herre sifrit | bi criemhilde saz ### in was ce hove erlovbet | davon so taten si daz
###### 745 | ### der wirt mit sinem wibe | stvnt vf sa cehant ### wol wart enpfangen gere | von pvrgvnden lant ### mit sinen hergesellen | di gvntheres man ### geren den vil richen | bat man an den saedel gan
###### 746 | ### erlovbet vns di botschapft | e daz wir sitzen gen ### vns waegemvede geste | lat vns di wile sten ### wir sveln iv sagen maere | waz iv enboten hat ### gvnther vnd prvennhilt | ir dinch vil hohenliche stat
###### 747 | ### vnt ovch waz vrov vote | iwer mvter her enbot ### giselher der ivnge | vnt ovch her gernot ### vnt iwer besten mage | di habent vns her gesant ### di enbietent iv ir dienest | vzer gvntheres lant
###### 748 | ### nv lon in got sprach sifrit | ich getruwe in harte wol ### triwen vnt gvtes | also man vrivnden sol ### alsam tvt ovch ir swester | ir svlt vns maere sagen ### ob vnser lieben vrivnde | da heime iht hohes mvtes tragen
###### 749 | ### sit daz wir von in shienden | hat in iemen iht getan ### den minen choenemagen | daz svlt ir mich wizen lan ### daz wil in immer | mit triwen helfen tragen ### vnze daz ir viende | den minen dienest mvezen klagen
###### 750 | ### do sprach der margrave gere | ein reche vil gvt ### si sint in allen tvgenden | so rehte hohgemvt ### si ladent ivch ce rine | ceiner hochgecit ### si saehen ivch vil gerne | daz ir des ane zwifel sit
###### 751 | ### vnde pitent mine vrowen | si svl mit iv dar chvmen ### swenne daz der vient | ein ende habe genvmen ### vor disen svnewenden | so wolden si ivch saehen ### do sprach der starche sifrit | daz chvnde mvelich geschaehen
###### 752 | ### do sprach aber gere | von bvergvnden lant ### iwer mvter vote | hat ivch gemant ### gernot vnt giselher | ir svlt in niht versagen ### daz ir in sit so verre | daz hoer ich taegeliche chlagen
###### 753 | ### prvennhilt min vrowe | vnt alle ir maegedin ### di vrevnt sich der maere | vnt ob iz mvege sin ### daz si ivch noch gesaehen | daz gaebe in hohen mvt ### do dvhten disiv maere | di shoenen criemhilde gvt
###### 754 | ### gere was ir sippe | der wirt in sitzen hiez ### den gesten hiez er shenchen | niht langer man daz liez ### do was ovch chvmen sigemvnt | da er di boten sach ### der herre vrivnthliche | zv den bvergvnden sprach
###### 755 | ### sit willechomen ir rechen | ir gvntheres man ### sit daz criemhilt | ce wibe gewan ### sifrit der min svn | man sold ivch dicker saehen ### hie in disem lande | wolt ir vns vrivntschepfte iehen
###### 756 | ### si sprachen swenne er wolde | si solden gerne chomen ### in wart ir michel mvede | mit vrevden vil benomen ### di boten bat man sitzen | spise man in trvch ### do hiez do gaeben sifrit | sinen gesten genvch
###### 757 | ### si mvsen da beliben | bevollen niwn tage ### des heten endechlichen | di snellen ritter chlage ### daz si niht wider solden | riten in ir lant ### do het der chvnich sifrit | nach sinen vrivnden gesant
###### 758 | ### er vragte waz si rieten | ob si solden an den rin ### ez hat nach mir gesendet | gvnther der frivnt min ### er vnt sine mage | dvrch eine hohgecit ### nv choeme ich im vil gerne | want daz sin lant ce verre lit
###### 759 | ### vnt bitten criemhilde | daz si mit mir var ### nv ratet liebe vrivnde | wi sol ich chomen dar ### vnt sold ich herverten | dvrch si in drizech lant ### da mvesen dienen gerne | hin div sifrides hant
###### 760 | ### do sprachen sine rechen | habt ir der reise mvt ### hin cer hohgecite | wir raten waz ir tvt ### ir svlt mit tvsent recken | riten an den rin ### so mveget ir wol mit eren | da cen bvrgvnden sin
###### 761 | ### do sprach von niderlande | der herre sigemvnt ### welt ir cer hohgecite | wan tvt ir mir daz chvnt ### ob iz iv niht versmahet | so rit ich mit iv dar ### ich fvere hvndert daegene | damite mer ich iwer schar
###### 762 | ### vnd welt ir mit vns riten | vil leiber vater min ### sprach der chvene sifrit | vil vro sol ich des sin ### iner tagen zwelven | so rvm ich miniv lant ### alle di es do gerten | den gap man ross vnt ovch gewant
###### 763 | ### do der chvenich edele | der reise hete mvt ### do hiez man widerriten | di snellen boten gvt ### den sinen choenemagen | enbot er an den rin ### er wolde harte gerne | da cir hochgeciten sin
###### 764 | ### sifrit vnt criemhilt | also wir horen sagen ### so vil den boten gaben | daz iz niht mohten tragen ### ir moere heim ce lande | er was ein richer man ### ir starchen sovmaere | di treip man vroeliche dan
###### 765 | ### ir volch chleidete sifrit | vnt ovch sigemvnt ### eckewart der grave | der hiez an der stvnt ### vrowen chleider svchen | div besten div man vant ### oder iender chvnd erwaerben | veber al sifrides lant
###### 766 | ### di saetele zv den schilden | bereiten man began ### rittern vnt vrowen | di mit in solden dan ### den gap man swaz si wolden | daz in niht gebrast ### do braht er sinen vrivnden | vil manigen herlichen gast
###### 767 | ### den boten zogete sere | ce lande vf den waegen ### do chom cen bvergvnden | gere der daegen ### er wart vil wol enpfangen | do erbeizten si ce tal ### von rossen vnt von moeren | fvr den giselheres sal
###### 768 | ### di tvmmen vnt di wisen | giengen so man tvt ### vragen vmbe maere | do sprach der riter gvt ### swenne ich se sage dem chvenige | da horet si cehant ### er gi mit den gesellen | da er gvntheren vant
###### 769 | ### der chvnich von grozer liebe | von dem saedele spranch ### daz si so balde chomen | des sagte er in do danch ### prvennhilt div schoene | gvnther cem boten sprach ### wi gehabt sich sifrit | von dem mir liebes vil gesach
###### 770 | ### do sprach der chvene gere | da wart er vrovden rot ### er vnt iwer swester | nie vrivnde baz enbot ### so getriwiv maere | deheiner slahte man ### als iv der herre sifrit | vnd ovch sin vater hat getan
###### 771 | ### do sprach ce dem marchgraven | des edelen chvniges wip ### nv sagt mir chvmet vns criemhilt | hat noch ir schoner lip ### behalten iht der zvehte | der si wol chvnde pflaegen ### si chvmt iv sicherlichen | so sprach do gere der daegen
###### 772 | ### vte bat do drate | di boten fver sich gen ### do mohte man an ir vrage | harte wol versten ### daz si daz horte gerne | was criemhilt noch gesvnt ### er sagete wi er si fvende | vnt daz si chome in chvrcer stvnt
###### 773 | ### ovch wart von in div gabe | ce hove niht verdeit ### di in gap her sifrit | golt vnd ovch div chleit ### daz brahte man ce sehene | der drier chvenige man ### der ir vil grozen milte | wart in danchen getan
###### 774 | ### er mach sprach do hagene | von im sampfte geben ### ern chvnd ez niht verswenden | vnt solder immer laeben ### hort der nibelvnge | beslozen hat sin hant ### hey solder rhvmen iemer | in der bvergonden lant
###### 775 | ### allez daz gesinde | vrevte sich darzv ### daz si chomen solden | spate vnt vrv ### ia waren vil vmmvezech | der drier chvenege man ### vil manich hergesidele | man do rihten began
###### 776 | ### hvnolt der chvene | vnd sindolt der daegen ### di heten vil vmmvoze | di zit si mvsen pflaegen ### trvhsaezen vnt shenchen | ce rihten manige banch ### des half in ovch her ortwin | des sagete in gvnther danch
###### 777 | ### rvmolt der chvchenmeister | wi wol er rihte sit ### di sinen vndertanen | vil manigen kezel wit ### haeven vnt pfannen | hey waz man der da vant ### do bereite man do spise | di da chomen in daz lant

<<< Übersicht <<< vorige Seite nächste Seite >>>